#  Copyright (c) 2013 David Caldwell,  All Rights Reserved. -*- cperl -*-

package App::PerlCalc;

our $VERSION = '1.2.0';

__END__

=head1 NAME

PC - A simple but feature filled command line Perl calculator

=head1 DESCRIPTION

This is a stub to appease the CPAN gods. Please see L<pc> for the
documentation.

=head1 SEE ALSO

L<PC, The Perl Calculator|http://porkrind.org/missives/pc-perl-calculator>

L<Project Source Code|https://github.com/caldwell/pc>

=head1 COPYRIGHT

This library is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

Copyright (C) 2003-2009 David Caldwell

=head1 AUTHOR

David Caldwell <david@porkrind.org>

=cut

1;
